#!/usr/bin/env ruby

###
## Copyright 2009 by Adron Systems LLC, Laporte, MN  56461.
## Permission is granted to copy, distribute and/or modify this document.
##
##   Purpose: Interface demo routine for ASE:Reader and related classes.
##
##  $RCSfile: ExtractTester.rb $
##
##     $Date: 2009/06/16 19:08:23 $
## $Revision: 1.2 $
###

# Load the Vx Extract interface library.
require 'ExtractLoad'


# Open a GC/MS data file for reading.
#rdr = ASE::Reader.new('TKF', 'd:\\my data\\eastman\\c8484s2.tkf')
rdr = ASE::Reader.new('TKF', 'd:\\my data\\supelco\\fc-43-detected.tkf')
#rdr = ASE::Reader.new('d:\\my data\\supelco\\fc-43-detected.tkf')
printf("File type : %s\n", ASE::Reader.descriptionOfKind(rdr.kind))
puts

# Retrieve time-of-injection as an ASE::Time object
tm_inj = rdr.timeOfInjection

# Display time in various example formats.
img_inj  = tm_inj.image(ASE::Time.FORMAT_ANDI_DATETIME)
printf("UTC   injection time: %s\n", img_inj)

img_inj = tm_inj.imageBiased(ASE::Time.FORMAT_VECTOR2_DATETIME, -300)
printf("Bias (-300 min) time: %s\n", img_inj)

img_inj = tm_inj.imageLocal(ASE::Time.FORMAT_LONG_ORDERED_DATETIME)
printf("Local injection time: %s\n", img_inj)
puts


# Locate scan indices for times 10 to 20 minutes.
# Note: Converting from seconds to minutes using 60*.
range_itv = (10..20)
index_first = rdr.scanAtInterval( false, 60*range_itv.first )
index_last  = rdr.scanAtInterval( true , 60*range_itv.last  )

# Retrieve actual scan intervals for found indices.
itv_first = rdr.intervalOfScan( index_first )
itv_last  = rdr.intervalOfScan( index_last  )

# Print out found indices and actual scan interval in minutes.
# Note: Converting from minutes to seconds usings /60.
printf( "At index %d, interval is %g minutes\n", index_first, itv_first / 60.0 )
printf( "At index %d, interval is %g minutes\n", index_last , itv_last  / 60.0 )
puts

if (cOfScans = rdr.numberOfScans)

  # Use middle scan index for examples.
  index=cOfScans>>1
  printf("Scan interval (s) for index (%d) : %.9g\n", index, rdr.intervalOfScan(index))
  printf("Scan  summation   for index (%d) : %d\n", index, rdr.summationOfScan(index))

  # Exercise mass/intensity point using scan base peak.
  pkBase = rdr.basePeakOfScan(true, index)
  printf("Nominal base peak for index (%d) : mass(%g), intensity(%d)\n", index, pkBase.mass, pkBase.intensity)
  pkBase = rdr.basePeakOfScan(false, index)
  printf("        Base peak for index (%d) : mass(%g), intensity(%d)\n", index, pkBase.mass, pkBase.intensity)
  printf("Scaled  base peak for index (%d) : mass(%d), intensity(%d)\n", index, pkBase.scaled_mass, pkBase.intensity)

  # Extract a single ion intensity.
  masssingle=131
  printf("    Ion intensity for index (%d) : mass(%d) -> intensity(%d)\n", index, masssingle, rdr.extractIon(index, masssingle))
  puts

  # Mass range of for all acquired spectra.
  range_mass = rdr.completeScanRange
  printf("Data scan range is from %d to %d\n", range_mass.first, range_mass.last)
  puts

  # Example of ion m/z values.
  masssingle=131
  massrange=100..200
  masslist=[55, 69, 83, 111, 126, 131, 252]

  aTIC=Array.new(cOfScans)
  aIon=Array.new(cOfScans)
  rdr.extractChromatogram(   ASE::TIC, aTIC )
  rdr.extractChromatogram( masssingle, aIon )
  printf("Example of ion chromatogram extraction by various means:\n\n")
  printf("  Interval        TIC       Sum   %5d", masssingle)
  masslist.each do |j| printf("  %8d", j) end
  puts
  printf("  --------      -----     -----   -----")
  masslist.each do |j| printf("     -----") end
  puts
  intensities=Array.new(masslist.size)
  0.upto(cOfScans-1) do |i|
#    ionsum = rdr.extractIon(i, massrange)
     ionsum = rdr.extractIon(i, masslist)
     rdr.extractIons(i, masslist, intensities)
     printf("%10.4f : %8d  %8d  %6d", aTIC[i].interval, aTIC[i].intensity, ionsum, aIon[i].intensity)
     intensities.each do |j| printf("  %8d", j) end
     puts
  end
  puts

  # Extract all mass spectra.
  # Alternate scans with "nominal" and "stored" masses.
  apeaks=Array.new(50)
  nominal = false
  0.upto(cOfScans-1) do |i|
    nominal  = nominal ? false : true
    cOfPeaks = rdr.extractScan(nominal, i, apeaks)
    printf("Number of peaks in scan (%d) : %d\n", i, cOfPeaks )
    printf("Scan interval for index (%d) : %.9g\n", i, rdr.intervalOfScan(i))
    if (cOfPeaks)
      0.upto(cOfPeaks-1) do |j|
        printf( "%7.3f : %7d\n", apeaks[j].mass, apeaks[j].intensity )
      end
    end
    puts
  end
  puts

end

# Miscellaneous constants.
printf("Mass resolution factor       : %g\n", 1.0 / ASE::MI::SCALE_FACTOR_MASS)
printf("Minimum ion mass (m/z) value : %6d\n", ASE::MI::MIN_MASS)
printf("Maximum ion mass (m/z) value : %6d\n", ASE::MI::MAX_MASS)
printf("Minimum allowed intensity value : %d\n",  ASE::MIN_INTENSITY)
printf("Maximum allowed intensity value :  %d\n", ASE::MAX_INTENSITY)




## Hold for possible enhancement?
#
#  # Output interval of scan (seconds) w/o trailing zeros or decimal point.
#  str_itv = sprintf("%.6f", itv_scan)
#  m1,m2 = /(?:(\d*\.\d*[1-9])|(\d*))/.match(str_itv).captures
#  fout.printf("IntervalOfScan=%s\n", m1 ? m1 : m2 )
