#!/usr/bin/env ruby

###
## Copyright 2009 by Adron Systems LLC, Laporte, MN  56461.
## Permission is granted to copy, distribute and/or modify this document.
##
##   Purpose: Output file (header) information to stdout or output file.
##
##  Location: Adron\Engine\Macros.Ruby
##  Filename: FileInfo.rb
##
##   Started: 2009/06/01
##   Updated:[2016/04/02]
###

# Load the Vx Extract interface library.
require 'ExtractLoad'


###
## Routine displayHelp :
###

def displayHelp
  system("cls")
  printf("Data file header information display utility.  (Extract release : %s)\n", ASE::EXTRACT_RELEASE) ;
  puts
  printf("  %s [InFileName] [OutFileName] \n", File.basename($0))
  puts
  print("Options:\n")
  print("  InFileName   File to read (input) is first name specified.\n")
  print("  OutFileName  Output file is second name specified.\n")
  print("               If name not specified, then output goes to stdout.\n")
  puts
  print("  Optional items shown in [].\n")
  print("  No parameters generates this help screen.\n")
  puts
  print(ASE::ADRON_COPYRIGHT)
end


###
## Routine displayInfo :
###

def displayInfo( rdr, fout )
  fn = File.expand_path(rdr.nameOfFile)
  fn.gsub!( File::SEPARATOR, File::ALT_SEPARATOR )
  fout.print(fn, "\n")
  fout.printf("Instrument      :  %s\n", rdr.nameOfInstrument)

  inj_time = rdr.timeOfInjection
  fout.printf("Injection Time  :  %s\n", inj_time.imageLocal(ASE::Time.FORMAT_ORDERED_DATETIME))
  fout.printf("Sample Info     :  %s\n", rdr.nameOfSample)
  fout.printf("Sample Account  :  %s\n", rdr.nameOfSampleAccount)
  fout.printf("Quality Control :  %s\n", rdr.qcType)
  fout.printf("Operator        :  %s\n", rdr.nameOfOperator)
  fout.printf("Calibration Name:  %s\n", rdr.nameOfCalibration)
  fout.printf("Method Name     :  %s\n", rdr.nameOfMethod)
  fout.printf("Solvent Scans   :  %d\n", rdr.numberOfSolventScans)
  if ( !ENV['PROENGINE'].nil?)
  fout.printf("Scans  (actual) :  %d\n", rdr.numberOfActualScans)
  fout.printf("Scans    (demo) :  %d\n", rdr.numberOfDemoScans)
  end
  fout.printf("Scans (spectra) :  %d\n", rdr.numberOfScans)
  fout.printf("Vial Number     :  %d\n", rdr.vialNumber)
  fout.printf("Injection volume:  %g\n", rdr.injectionVolume)
  fout.printf("Profile data?   :  %s\n", rdr.isProfile ? 'Raw' : 'Peak detected')

  lines = rdr.descriptionLines
  if (lines.nil?) || ( 1 == lines.length )
    fout.printf("Description     :  %s\n", rdr.description)
  else
    fout.printf("Description >>\n")
    lines.each do |line|
      fout.print( ">> ", line, "\n" )
    end
  end
end


###
## Entrance :	
###

# No arguments, then display help screen.
if (ARGV.empty?)
  displayHelp
  Process.exit
end

# Open a ASE::Reader object.
begin
  rdr = ASE::Reader.new( ARGV[0] )
rescue Exception
  raise "Unable to create ASE::Reader object."
end

# Second argument is optional output file name.
fout = (nil != ARGV[1]) ? File.open(ARGV[1], "w+") : $stdout

# Display file information fields.
displayInfo( rdr, fout )
